@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.98 2006/07/16 12:48:33 mbarbon Exp $
+## RCS-ID:      $Id: Wx.pm,v 1.100 2006/08/05 13:18:46 mbarbon Exp $
 ## Copyright:   (c) 2000-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.54';
+$VERSION = '0.55';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -309,6 +309,12 @@ Wx - interface to the wxWidgets cross-platform GUI toolkit
 
     use Wx;
 
+    my $app = Wx::SimpleApp->new;
+    my $frame = Wx::Frame->new( undef, -1, 'Hello, world!' );
+
+    $frame->Show;
+    $app->MainLoop;
+
 =head1 DESCRIPTION
 
 The Wx module is a wrapper for the wxWidgets (formerly known as wxWindows)
