@@ -12,7 +12,7 @@ our $alien_key = 'XXXALIENXXX';
     $Wx::dlls = XXXDLLSXXX;
 }
 
-$VERSION = '0.54'; # bootstrap will catch wrong versions
+$VERSION = '0.55'; # bootstrap will catch wrong versions
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -44,8 +44,8 @@ sub wx_boot($$) {
 sub _alien_path {
   return if defined $wx_path;
   foreach ( @INC ) {
-    if( -d "$_/Alien/wxWidgets/XXXALIENXXX" ) {
-      $wx_path = "$_/Alien/wxWidgets/XXXALIENXXX/lib";
+    if( -d "$_/Alien/wxWidgets/XXXALIENDXXX" ) {
+      $wx_path = "$_/Alien/wxWidgets/XXXALIENDXXX/lib";
       last;
     }
   }
