@@ -5,8 +5,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     17/08/2001
-## RCS-ID:      $Id: make_ovl_list.pl,v 1.13 2004/10/19 20:28:15 mbarbon Exp $
-## Copyright:   (c) 2001-2003 Mattia Barbon
+## RCS-ID:      $Id: make_ovl_list.pl,v 1.16 2006/07/22 20:21:18 mbarbon Exp $
+## Copyright:   (c) 2001-2003, 2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -83,7 +83,12 @@ my %name2type =
    wehd => 'Wx::EvtHandler',
    wtid => 'Wx::TreeItemId',
    wfon => 'Wx::Font',
+   wdc  => 'Wx::DC',
    wfrm => 'Wx::Frame',
+   wgbp => 'Wx::GBPosition',
+   wgbs => 'Wx::GBSpan',
+   wgbi => 'Wx::GBSizerItem',
+   wilo => 'Wx::IconLocation',
    wist => 1,
    wost => 1,
    num  => 1,
@@ -135,7 +140,6 @@ print OUT <<EOT;
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     17/ 8/2001
-## RCS-ID:      
 ## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
